# Copyright 2015 by Toben "Narcolapser" Archer. All Rights Reserved.
#
# Permission to use, copy, modify, and distribute this software and its documentation for any purpose 
# and without fee is hereby granted, provided that the above copyright notice appear in all copies and 
# that both that copyright notice and this permission notice appear in supporting documentation, and 
# that the name of Toben Archer not be used in advertising or publicity pertaining to distribution of 
# the software without specific, written prior permission. TOBEN ARCHER DISCLAIMS ALL WARRANTIES WITH 
# REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT 
# SHALL TOBEN ARCHER BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES 
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE 
# OR OTHER TORTIOUS ACTION, ARISING OUT
# OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

'''
Python library for interfacing with the Microsoft Office 365 online. 
'''
#__all__ = ['attachment','cal','contact','event','group','inbox','message','schedule']

# This imports all the libraries into the local namespace. This makes it easy to work with.

from .contact import Contact
from .group import Group
from .cal import Calendar
from .event import Event
from .attachment import Attachment
from .inbox import Inbox
from .message import Message
from .schedule import Schedule

#To the King!



from O365.contact import Contact
from O365.group import Group
import logging
import json
import requests
import time

log = logging.getLogger(__name__)

class Event( object ):
	'''
	Class for managing the creation and manipluation of events in a calendar. 
	
	Methods:
		create -- Creates the event in a calendar.
		update -- Sends local changes up to the cloud.
		delete -- Deletes event from the cloud.
		toJson -- returns the json representation.
		fullcalendarioJson -- gets a specific json representation used for fullcalendario.
		getSubject -- gets the subject of the event.
		getBody -- gets the body of the event.
		getStart -- gets the starting time of the event. (struct_time)
		getEnd -- gets the ending time of the event. (struct_time)
		getAttendees -- gets the attendees of the event.
		addAttendee -- adds an attendee to the event. update needs to be called for notification.
		setSubject -- sets the subject line of the event.
		setBody -- sets the body of the event.
		setStart -- sets the starting time of the event. (struct_time)
		setEnd -- sets the starting time of the event. (struct_time)
		setAttendees -- sets the attendee list.
		setStartTimeZone -- sets the timezone for the start of the event item.
		setEndTimeZone -- sets the timezone for the end of the event item.
		
	Variables:
		time_string -- Formated time string for translation to and from json.
		create_url -- url for creating a new event.
		update_url -- url for updating an existing event.
		delete_url -- url for deleting an event.
	'''
	#Formated time string for translation to and from json.
	time_string = '%Y-%m-%dT%H:%M:%SZ'
	#takes a calendar ID
	create_url = 'https://outlook.office365.com/api/v1.0/me/calendars/{0}/events'
	#takes current event ID
	update_url = 'https://outlook.office365.com/api/v1.0/me/events/{0}'
	#takes current event ID
	delete_url = 'https://outlook.office365.com/api/v1.0/me/events/{0}'


	def __init__(self,json=None,auth=None,cal=None):
		'''
		Creates a new event wrapper.
		
		Keyword Argument:
			json (default = None) -- json representation of an existing event. mostly just used by
			this library internally for events that are downloaded by the callendar class.
			auth (default = None) -- a (email,password) tuple which will be used for authentication
			to office365.
			cal (default = None) -- an instance of the calendar for this event to associate with.
		'''
		self.auth = auth
		self.calendar = cal
		self.attendees = []

		if json:
			self.json = json
			self.isNew = False
		else:
			self.json = {}


	def create(self,calendar=None):
		'''
		this method creates an event on the calender passed.

		IMPORTANT: It returns that event now created in the calendar, if you wish
		to make any changes to this event after you make it, use the returned value
		and not this particular event any further.
		
		calendar -- a calendar class onto which you want this event to be created. If this is left
		empty then the event's default calendar, specified at instancing, will be used. If no 
		default is specified, then the event cannot be created.
		
		'''
		if not self.auth:
			log.debug('failed authentication check when creating event.')
			return False

		if calendar:
			calId = calendar.calendarId
			self.calendar = calendar
			log.debug('sent to passed calendar.')
		elif self.calendar:
			calId = self.calendar.calendarId
			log.debug('sent to default calendar.')
		else:
			log.debug('no valid calendar to upload to.')
			return False

		headers = {'Content-type': 'application/json', 'Accept': 'application/json'}

		log.debug('creating json for request.')
		data = json.dumps(self.json)

		response = None
		try:
			log.debug('sending post request now')
			response = requests.post(self.create_url.format(calId),data,headers=headers,auth=self.auth)
			log.debug('sent post request.')
		except Exception as e:
			if response:
				log.debug('response to event creation: %s',str(response))
			else:
				log.error('No response, something is very wrong with create: %s',str(e))
			return False

		log.debug('response to event creation: %s',str(response))
		return Event(response.json(),self.auth,calendar)

	def update(self):
		'''Updates an event that already exists in a calendar.'''
		if not self.auth:
			return False

		if self.calendar:
			calId = self.calendar.calendarId
		else:
			return False


		headers = {'Content-type': 'application/json', 'Accept': 'application/json'}

		data = json.dumps(self.json)

		response = None
		try:
			response = requests.patch(self.update_url.format(self.json['Id']),data,headers=headers,auth=self.auth)
			log.debug('sending patch request now')
		except Exception as e:
			if response:
				log.debug('response to event creation: %s',str(response))
			else:
				log.error('No response, something is very wrong with update: %s',str(e))
			return False

		log.debug('response to event creation: %s',str(response))

		return Event(response.json(),self.auth)


	def delete(self):
		'''
		Delete's an event from the calendar it is in.
		
		But leaves you this handle. You could then change the calendar and transfer the event to 
		that new calendar. You know, if that's your thing.
		'''
		if not self.auth:
			return False

		headers = {'Content-type': 'application/json', 'Accept': 'text/plain'}

		response = None
		try:
			log.debug('sending delete request')
			response = requests.delete(self.delete_url.format(self.json['Id']),headers=headers,auth=self.auth)

		except Exception as e:
			if response:
				log.debug('response to deletion: %s',str(response))
			else:
				log.error('No response, something is very wrong with delete: %s',str(e))
			return False

		return response

	def toJson(self):
		'''
		Creates a JSON representation of the calendar event.
		
		oh. uh. I mean it simply returns the json representation that has always been in self.json.
		'''
		return self.json

	def fullcalendarioJson(self):
		'''
		returns a form of the event suitable for the vehicle booking system here.
		oh the joys of having a library to yourself! 
		'''
		ret = {}
		ret['title'] = self.json['Subject']
		ret['driver'] = self.json['Organizer']['EmailAddress']['Name']
		ret['driverEmail'] = self.json['Organizer']['EmailAddress']['Address']
		ret['start'] = self.json['Start']
		ret['end'] = self.json['End']
		ret['IsAllDay'] = self.json['IsAllDay']
		return ret

	def getSubject(self):
		'''Gets event subject line.'''
		return self.json['Subject']

	def getBody(self):
		'''Gets event body content.'''
		return self.json['Body']['Content']

	def getStart(self):
		'''Gets event start struct_time'''
		return time.strptime(self.json['Start'], self.time_string)

	def getEnd(self):
		'''Gets event end struct_time'''
		return time.strptime(self.json['End'], self.time_string)

	def getAttendees(self):
		'''Gets list of event attendees.'''
		return self.json['Attendees']

	def setSubject(self,val):
		'''sets event subject line.'''
		self.json['Subject'] = val

	def setBody(self,val):
		'''sets event body content.'''
		cont = False

		while not cont:
			try:
				self.json['Body']['Content'] = val
				self.json['Body']['ContentType'] = 'Text'
				cont = True
			except:
				self.json['Body'] = {}

	def setStart(self,val):
		'''
		sets event start time.
		
		Argument:
			val - this argument can be passed in three different ways. You can pass it in as a int
			or float, in which case the assumption is that it's seconds since Unix Epoch. You can
			pass it in as a struct_time. Or you can pass in a string. The string must be formated
			in the json style, which is %Y-%m-%dT%H:%M:%SZ. If you stray from that in your string
			you will break the library.
		'''
		if isinstance(val,time.struct_time):
			self.json['Start'] = time.strftime(self.time_string,val)
		elif isinstance(val,int):
			self.json['Start'] = time.strftime(self.time_string,time.gmtime(val))
		elif isinstance(val,float):
			self.json['Start'] = time.strftime(self.time_string,time.gmtime(val))
		else:
			#this last one assumes you know how to format the time string. if it brakes, check
			#your time string!
			self.json['Start'] = val

	def setEnd(self,val):
		'''
		sets event end time.
		
		Argument:
			val - this argument can be passed in three different ways. You can pass it in as a int
			or float, in which case the assumption is that it's seconds since Unix Epoch. You can
			pass it in as a struct_time. Or you can pass in a string. The string must be formated
			in the json style, which is %Y-%m-%dT%H:%M:%SZ. If you stray from that in your string
			you will break the library.
		'''
		if isinstance(val,time.struct_time):
			self.json['End'] = time.strftime(self.time_string,val)
		elif isinstance(val,int):
			self.json['End'] = time.strftime(self.time_string,time.gmtime(val))
		elif isinstance(val,float):
			self.json['End'] = time.strftime(self.time_string,time.gmtime(val))
		else:
			#this last one assumes you know how to format the time string. if it brakes, check
			#your time string!
			self.json['End'] = val

	def setAttendees(self,val):
		'''
		set the attendee list.
		
		val: the one argument this method takes can be very flexible. you can send:
			a dictionary: this must to be a dictionary formated as such:
				{"EmailAddress":{"Address":"recipient@example.com"}}
				with other options such ass "Name" with address. but at minimum it must have this.
			a list: this must to be a list of libraries formatted the way specified above,
				or it can be a list of libraries objects of type Contact. The method will sort
				out the libraries from the contacts. 
			a string: this is if you just want to throw an email address. 
			a contact: type Contact from this library. 
		For each of these argument types the appropriate action will be taken to fit them to the 
		needs of the library.
		'''
		self.json['Attendees'] = []
		if isinstance(val,list):
			self.json['Attendees'] = val
		elif isinstance(val,dict):
			self.json['Attendees'] = [val]
		elif isinstance(val,str):
			if '@' in val:
				self.addAttendee(val)
		elif isinstance(val,Contact):
			self.addAttendee(val)
		elif isinstance(val,Group):
			self.addAttendee(val)
		else:
			return False
		return True
	
	def setStartTimeZone(self,val):
		'''sets event start timezone'''
		self.json['StartTimeZone'] = val

	def setEndTimeZone(self,val):
		'''sets event end timezone'''
		self.json['EndTimeZone'] = val

	def addAttendee(self,address,name=None):
		'''
		Adds a recipient to the attendee list.
		
		Arguments:
		address -- the email address of the person you are sending to. <<< Important that.
			Address can also be of type Contact or type Group.
		name -- the name of the person you are sending to. mostly just a decorator. If you
			send an email address for the address arg, this will give you the ability
			to set the name properly, other wise it uses the email address up to the
			at sign for the name. But if you send a type Contact or type Group, this
			argument is completely ignored.
		'''
		if isinstance(address,Contact):
			self.json['Attendees'].append(address.getFirstEmailAddress())
		elif isinstance(address,Group):
			for con in address.contacts:
				self.json['Attendees'].append(address.getFirstEmailAddress())
		else:
			if name is None:
				name = address[:address.index('@')]
			self.json['Attendees'].append({'EmailAddress':{'Address':address,'Name':name}})

	def setLocation(self,loc):
		'''
		Sets the event's location.

		Arguments:
		loc -- two options, you can send a dictionary in the format discribed here:
		https://msdn.microsoft.com/en-us/office/office365/api/complex-types-for-mail-contacts-calendar#LocationBeta
		this will allow you to set address, coordinates, displayname, location email
		address, location uri, or any combination of the above. If you don't need that much
		detail you can simply send a string and it will be set as the locations display
		name. If you send something not a string or a dict, it will try to cast whatever
		you send into a string and set that as the display name.
		'''
		if 'Location' not in self.json:
			self.json['Location'] = {"Address":None}

		if isinstance(loc,dict):
			self.json['Location'] = loc
		else:
			self.json['Location']['DisplayName'] = str(loc)

	def getLocation(self):
		'''
		Get the current location, if one is set.
		'''
		if 'Location' in self.json:
			return self.json['Location']
		return None
		
			

#To the King!



'''
This file contains the functions for working with attachments. Including the ability to work with the
binary of the file directly. The file is stored locally as a string using base64 encoding. 
'''

import base64
import logging
import json
import requests
import sys

log = logging.getLogger(__name__)

class Attachment( object ):
	'''
	Attachment class is the object for dealing with attachments in your messages. To add one to
	a message, simply append it to the message's attachment list (message.attachments). 

	these are stored locally in base64 encoded strings. You can pass either a byte string or a
	base64 encoded string tot he appropriate set function to bring your attachment into the
	instance, which will of course need to happen before it could be mailed.
	
	Methods:
	isType - compares file extension to extension given. not case sensative.
	getType - returns file extension.
	save - save attachment locally.
	getByteString - returns the attached file as a byte string.
	setByteString - set the attached file using a byte string.
	getBase64 - returns the attached file as a base64 encoded string.
	setBase64 - set the attached file using a base64 encoded string.
	'''

	create_url = 'https://outlook.office365.com/api/v1.0/me/messages/{0}/attachments'

	def __init__(self,json=None,path=None):
		'''
		Creates a new attachment class, optionally from existing JSON.
		
		Keyword Arguments:
		json -- json to create the class from. this is mostly used by the class internally when an
		attachment is downloaded from the cloud. If you want to create a new attachment, leave this
		empty. (default = None)
		path -- a string giving the path to a file. it is cross platform as long as you break
		windows convention and use '/' instead of '\'. Passing this argument will tend to
		the rest of the process of making an attachment. Note that passing in json as well
		will cause this argument to be ignored.
		'''
		if json:
			self.json = json
			self.isPDF = '.pdf' in self.json['Name'].lower()
		elif path:
			with open(path,'rb') as val:
				self.json = {'@odata.type':'#Microsoft.OutlookServices.FileAttachment'}
				self.isPDF = '.pdf' in path.lower()

				self.setByteString(val.read())
				try:
					self.setName(path[path.rindex('/')+1:])
				except:
					self.setName(path)
		else:
			self.json = {'@odata.type':'#Microsoft.OutlookServices.FileAttachment'}

	def isType(self,typeString):
		'''Test to if the attachment is the same type as you are seeking. Do not include a period.'''
		return '.'+typeString.lower() in self.json['Name'].lower()

	def getType(self):
		'''returns the file extension'''
		return self.json['Name'][self.json['Name'].rindex('.'):]

	def save(self,location):
		'''Save the attachment locally to disk.

		location -- path to where the file is to be saved.
		'''
		try:
			outs = open(location+'/'+self.json['Name'],'wb')
			outs.write(base64.b64decode(self.json['ContentBytes']))
			outs.close()
			log.debug('file saved locally.')
			
		except Exception as e:
			log.debug('file failed to be saved: %s',str(e))
			return False

		log.debug('file saving successful')
		return True

	def attach(self,message):
		'''
		This does the actual creating of the attachment as well as attaching to a message.

		message -- a Message type, the message to be attached to.
		'''
		mid = message.json['Id']

		headers = {'Content-type': 'application/json', 'Accept': 'application/json'}

		data = json.dumps(self.json)

		response = requests.post(self.create_url.format(mid),data,header=headers,auth=message.auth)
		log.debug('Response from server for attaching: {0}'.format(str(response)))

		return response

	def getByteString(self):
		'''Fetch the binary representation of the file. useful for times you want to
		skip the step of saving before sending it to another program. This allows
		you to make scripts that use linux pipe lines in their execution.
		'''
		try:
			return base64.b64decode(self.json['ContentBytes'])

		except Exception as e:
			log.debug('what? no clue what went wrong here. cannot decode attachment.')

		return False

	def getBase64(self):
		'''Returns the base64 encoding representation of the attachment.'''
		try:
			return self.json['ContentBytes']
		except Exception as e:
			log.debug('what? no clue what went wrong here. probably no attachment.')
		return False

	def getName(self):
		'''Returns the file name.'''
		try:
			return self.json['Name']
		except Exception as e:
			log.error('The attachment does not appear to have a name.')
		return False

	def setName(self,val):
		'''Set the name for the file.'''
		self.json['Name'] = val

	def setByteString(self,val):
		'''Sets the file for this attachment from a byte string.'''
		try:
			if sys.version_info[0] == 2:
				self.json['ContentBytes'] = base64.b64encode(val)
			else:
				self.json['ContentBytes'] = str(base64.encodebytes(val),'utf-8')
		except Exception as e:
			log.debug('error encoding attachment: {0}'.format(e))
			return False
		return True

	def setBase64(self,val):
		'''Sets the file for this attachment from a base64 encoding.'''
		try:
			base64.decodestring(val)
		except:
			log.error('tried to give me an attachment as a base64 and it is not.')
			raise
		self.json['ContentBytes'] = val
		return True

#To the King!



from O365.attachment import Attachment
from O365.contact import Contact
from O365.group import Group
import logging
import json
import requests

log = logging.getLogger(__name__)

class Message(object):
  '''
  Management of the process of sending, recieving, reading, and editing emails.

  Note: the get and set methods are technically superflous. You can get more through control over
  a message you are trying to craft throught he use of editing the message.json, but these
  methods provide an easy way if you don't need all the power and would like the ease.

  Methods:
          constructor -- creates a new message class, using json for existing, nothing for new.
          fetchAttachments -- kicks off the process that downloads attachments.
          sendMessage -- take local variables and form them to send the message.
          markAsRead -- marks the analougs message in the cloud as read.
          getSender -- gets a dictionary with the sender's information.
          getSenderEmail -- gets the email address of the sender.
          getSenderName -- gets the name of the sender, if possible.
          getSubject -- gets the email's subject line.
          getBody -- gets contents of the body of the email.
          addRecipient -- adds a person to the recipient list.
          setRecipients -- sets the list of recipients.
          setSubject -- sets the subject line.
          setBody -- sets the body.

  Variables:
          att_url -- url for requestiong attachments. takes message GUID
          send_url -- url for sending an email
          update_url -- url for updating an email already existing in the cloud.

  '''

  att_url = 'https://outlook.office365.com/api/v1.0/me/messages/{0}/attachments'
  send_url = 'https://outlook.office365.com/api/v1.0/me/sendmail'
  draft_url = 'https://outlook.office365.com/api/v1.0/me/folders/{folder_id}/messages'
  update_url = 'https://outlook.office365.com/api/v1.0/me/messages/{0}'

  def __init__(self, json=None, auth=None):
    '''
    Makes a new message wrapper for sending and recieving messages.

    Keyword Arguments:
            json (default = None) -- Takes json if you have a pre-existing message to create from.
            this is mostly used inside the library for when new messages are downloaded.
            auth (default = None) -- Takes an (email,password) tuple that will be used for
            authentication with office365.
    '''
    if json:
      self.json = json
      self.hasAttachments = json['HasAttachments']

    else:
      self.json = {'Message': {'Body': {}},
                   'ToRecipients': [], 'CcRecipients': [], 'BccRecipients': []}
      self.hasAttachments = False

    self.auth = auth
    self.attachments = []
    self.reciever = None

  def fetchAttachments(self):
    '''kicks off the process that downloads attachments locally.'''
    if not self.hasAttachments:
      log.debug('message has no attachments, skipping out early.')
      return False

    response = requests.get(self.att_url.format(
        self.json['Id']), auth=self.auth)
    log.info('response from O365 for retriving message attachments: %s', str(response))
    json = response.json()

    for att in json['value']:
      try:
        self.attachments.append(Attachment(att))
        log.debug('successfully downloaded attachment for: %s.', self.auth[0])
      except Exception as e:
        log.info('failed to download attachment for: %s', self.auth[0])

    return len(self.attachments)

  def sendMessage(self):
    '''takes local variabls and forms them into a message to be sent.'''

    headers = {'Content-type': 'application/json', 'Accept': 'text/plain'}

    try:
      data = {'Message': {'Body': {}}}
      data['Message']['Subject'] = self.json['Subject']
      data['Message']['Body']['Content'] = self.json['Body']['Content']
      data['Message']['Body']['ContentType'] = self.json['Body']['ContentType']
      data['Message']['ToRecipients'] = self.json['ToRecipients']
      data['Message']['CcRecipients'] = self.json['CcRecipients']
      data['Message']['BccRecipients'] = self.json['BccRecipients']
      data['Message']['Attachments'] = [att.json for att in self.attachments]
      data = json.dumps(data)
    except Exception as e:
      log.error(
          'Error while trying to compile the json string to send: {0}'.format(str(e)))
      return False

    response = requests.post(
        self.send_url, data, headers=headers, auth=self.auth)
    log.debug('response from server for sending message:' + str(response))
    log.debug("respnse body: {}".format(response.text))
    if response.status_code != 202:
      return False

    return True

  def markAsRead(self):
    '''marks analogous message as read in the cloud.'''
    read = '{"IsRead":true}'
    headers = {'Content-type': 'application/json', 'Accept': 'application/json'}
    try:
      response = requests.patch(self.update_url.format(
          self.json['Id']), read, headers=headers, auth=self.auth)
    except:
      return False
    return True

  def getSender(self):
    '''get all available information for the sender of the email.'''
    return self.json['Sender']

  def getSenderEmail(self):
    '''get the email address of the sender.'''
    return self.json['Sender']['EmailAddress']['Address']

  def getSenderName(self):
    '''try to get the name of the sender.'''
    try:
      return self.json['Sender']['EmailAddress']['Name']
    except:
      return ''

  def getSubject(self):
    '''get email subject line.'''
    return self.json['Subject']

  def getBody(self):
    '''get email body.'''
    return self.json['Body']['Content']

  def setRecipients(self, val, r_type="To"):
    '''
    set the recipient list.

    val: the one argument this method takes can be very flexible. you can send:
            a dictionary: this must to be a dictionary formated as such:
                    {"EmailAddress":{"Address":"recipient@example.com"}}
                    with other options such ass "Name" with address. but at minimum
                    it must have this.
            a list: this must to be a list of libraries formatted the way
                    specified above, or it can be a list of dictionary objects of
                    type Contact or it can be an email address as string. The
                    method will sort out the libraries from the contacts.
            a string: this is if you just want to throw an email address.
            a contact: type Contact from this dictionary.
            a group: type Group, which is a list of contacts.
    For each of these argument types the appropriate action will be taken
    to fit them to the needs of the library.
    '''
    log.debug("Entered SET_RECIPIENTS function with type: {}".format(r_type))
    self.json[r_type + 'Recipients'] = []

    if isinstance(val, list):
      for con in val:
        if isinstance(con, Contact):
          self.addRecipient(con, r_type=r_type)
        elif isinstance(con, str):
          if '@' in con:
            self.addRecipient(con, r_type=r_type)
        elif isinstance(con, dict):
          self.json[r_type + 'Recipients'].append(con)
    elif isinstance(val, dict):
      self.json[r_type + 'Recipients'] = [val]
    elif isinstance(val, str):
      if '@' in val:
        self.addRecipient(val, r_type=r_type)
    elif isinstance(val, Contact):
      self.addRecipient(val, r_type=r_type)
    elif isinstance(val, Group):
      for person in val:
        self.addRecipient(person, r_type=r_type)
    else:
      return False
    return True

  def addRecipient(self, address, name=None, r_type="To"):
    '''
    Adds a recipient to the recipients list.

    Arguments:
    address -- the email address of the person you are sending to. <<< Important that.
            Address can also be of type Contact or type Group.
    name -- the name of the person you are sending to. mostly just a decorator. If you
            send an email address for the address arg, this will give you the ability
            to set the name properly, other wise it uses the email address up to the
            at sign for the name. But if you send a type Contact or type Group, this
            argument is completely ignored.
    '''
    if isinstance(address, Contact):
      self.json[r_type + 'Recipients'].append(address.getFirstEmailAddress())
    elif isinstance(address, Group):
      for con in address.contacts:
        self.json[r_type + 'Recipients'].append(address.getFirstEmailAddress())
    else:
      if name is None:
        name = address[:address.index('@')]
      self.json[r_type + 'Recipients'].append(
          {'EmailAddress': {'Address': address, 'Name': name}})

  def setSubject(self, val):
    '''Sets the subect line of the email.'''
    self.json['Subject'] = val

  def setBody(self, val):
    '''Sets the body content of the email.'''
    cont = False

    while not cont:
      try:
        self.json['Body']['Content'] = val
        self.json['Body']['ContentType'] = 'Text'
        cont = True
      except:
        self.json['Body'] = {}

  def setBodyHTML(self, val=None):
    '''
    Sets the body content type to HTML for your pretty emails.

    arguments:
    val -- Default: None. The content of the body you want set. If you don't pass a
            value it is just ignored.
    '''
    cont = False

    while not cont:
      try:
        self.json['Body']['ContentType'] = 'HTML'
        if val:
          self.json['Body']['Content'] = val
        cont = True
      except:
        self.json['Body'] = {}

# To the King!


#!/usr/bin/env python

from distutils.core import setup

CLASSIFIERS = [
	'Development Status :: 4 - Beta',
	'Intended Audience :: Developers',
	'License :: OSI Approved :: Apache Software License',
	'Topic :: Office/Business :: Office Suites',
	'Topic :: Software Development :: Libraries'
]
long_desc = '''When I started making this library I was looking for something that would provide a simple interface to an office365 mailbox. I was creating a system that would allow people send an email to our printer without having to require they install drivers or be inside the office firewall (important for students). As I found working with the office API to be fairly easy, I quickly built up solid general use library for working with office 365. 

The objective here is to make it easy to make utilities that are to be run against an office 365 account. for example, the code for sending an email is:


from O365 import Message

authenticiation = ('YourAccount@office365.com','YourPassword')

m = Message(auth=authenticiation)

m.setRecipients('reciving@office365.com')

m.setSubject('I made an email script.')

m.setBody('Talk to the computer, cause the human does not want to hear it any more.')

m.sendMessage()


That's it. making and sending emails and events is now very simple and straight forward. I've used it for emailing the printer and creating a overview of our car booking system. simple, easy, but still in development. Any suggestions or advice are quite welcome at the projects github page:
https://github.com/Narcolapser/python-o365'''

setup(name='O365',
	version='0.9.6',
	description='Python library for working with Microsoft Office 365',
	long_description=long_desc,
	author='Toben Archer',
	author_email='sandslash+O365@gmail.com',
	maintainer='Toben Archer',
	maintainer_email='sandslash+O365@gmail.com',
	url='https://github.com/Narcolapser/python-o365',
	packages=['O365'],
	install_requires=['requests'],
	license='Apache 2.0',
	classifiers=CLASSIFIERS
	)


#so I don't have to keep looking it up: python setup.py sdist upload -r pypi
